@@ -277,12 +277,8 @@ clock_location_tile_fill (ClockLocationTile *this)
 
         priv->city_label = gtk_label_new (NULL);
         gtk_widget_set_margin_end (priv->city_label, 3);
-#if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (priv->city_label), 0.0);
         gtk_label_set_yalign (GTK_LABEL (priv->city_label), 0.0);
-#else
-        gtk_misc_set_alignment (GTK_MISC (priv->city_label), 0, 0);
-#endif
 
         head_section = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
         gtk_box_pack_start (GTK_BOX (head_section), priv->city_label, FALSE, FALSE, 0);
@@ -290,12 +286,8 @@ clock_location_tile_fill (ClockLocationTile *this)
         priv->time_label = gtk_label_new (NULL);
         gtk_label_set_width_chars (GTK_LABEL (priv->time_label), 20);
         gtk_widget_set_margin_end (priv->time_label, 3);
-#if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (priv->time_label), 0.0);
         gtk_label_set_yalign (GTK_LABEL (priv->time_label), 0.0);
-#else
-        gtk_misc_set_alignment (GTK_MISC (priv->time_label), 0, 0);
-#endif
 
         priv->weather_icon = gtk_image_new ();
         gtk_widget_set_valign (priv->weather_icon, GTK_ALIGN_START);
@@ -473,7 +465,7 @@ format_time (struct tm   *now,
                 }
         }
 
-        if (strftime (buf, sizeof (buf), format, now) <= 0) {
+        if (strftime (buf, sizeof (buf), format, now) == 0) {
                 strcpy (buf, "???");
         }
 
