@@ -37,6 +37,7 @@
 #include <glib/gi18n.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <gio/gio.h>
 
@@ -151,13 +152,9 @@ static void show_help(FishApplet* fish, const char* link_id)
 		uri = g_strdup_printf ("help:%s/%s", FISH_HELP_DOC, link_id);
 	else
 		uri = g_strdup_printf ("help:%s", FISH_HELP_DOC);
-#if GTK_CHECK_VERSION (3, 22, 0)
+
 	gtk_show_uri_on_window (NULL, uri, 
 			  gtk_get_current_event_time (), &error);
-#else
-	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (fish)), uri,
-		      gtk_get_current_event_time (), &error);
-#endif
 	g_free (uri);
 
 	if (error &&
@@ -560,7 +557,7 @@ static void display_about_dialog(GtkAction* action, FishApplet* fish)
 	char* descr;
 	char copyright[] = \
 		"Copyright \xc2\xa9 1998-2002 Free Software Foundation, Inc.\n"
-		"Copyright \xc2\xa9 2012-2017 MATE developers";
+		"Copyright \xc2\xa9 2012-2018 MATE developers";
 
 	authors[0] = g_strdup_printf(author_format, fish->name);
 	authors[1] = _("(with minor help from George)");
@@ -838,7 +835,7 @@ static void display_fortune_dialog(FishApplet* fish)
 			gtk_dialog_new_with_buttons (
 				"", NULL, 0,
 				_("_Speak again"), FISH_RESPONSE_SPEAK,
-				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+				"gtk-close", GTK_RESPONSE_CLOSE,
 				NULL);
 
 		gtk_window_set_icon_name (GTK_WINDOW (fish->fortune_dialog),
@@ -856,8 +853,8 @@ static void display_fortune_dialog(FishApplet* fish)
 
 		screen = gtk_widget_get_screen (GTK_WIDGET (fish));
 
-		gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
-					 &screen_width, &screen_height);
+		screen_width  = WidthOfScreen (gdk_x11_screen_get_xscreen (screen));
+		screen_height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen));
 
 		gtk_window_set_default_size (GTK_WINDOW (fish->fortune_dialog),
 					     MIN (600, screen_width  * 0.9),
@@ -888,13 +885,8 @@ static void display_fortune_dialog(FishApplet* fish)
 		gtk_label_set_ellipsize (GTK_LABEL (fish->fortune_label),
 					 PANGO_ELLIPSIZE_MIDDLE);
 		fish->fortune_cmd_label = gtk_label_new ("");
-#if GTK_CHECK_VERSION (3, 16, 0)
 		gtk_label_set_xalign (GTK_LABEL (fish->fortune_cmd_label), 0.0);
 		gtk_label_set_yalign (GTK_LABEL (fish->fortune_cmd_label), 0.5);
-#else
-		gtk_misc_set_alignment (GTK_MISC (fish->fortune_cmd_label),
-					0, 0.5);
-#endif
 
 		vbox = gtk_dialog_get_content_area (GTK_DIALOG (fish->fortune_dialog));
 		gtk_box_pack_start (GTK_BOX (vbox),
@@ -995,9 +987,6 @@ static void display_fortune_dialog(FishApplet* fish)
 
 static void name_changed_notify(GSettings* settings, gchar* key, FishApplet* fish)
 {
-	if (fish->source_id == 0)
-		return;
-
 	char *value;
 
 	value = g_settings_get_string (settings, key);
@@ -1023,9 +1012,6 @@ static void name_changed_notify(GSettings* settings, gchar* key, FishApplet* fis
 
 static void image_changed_notify(GSettings* settings, gchar* key, FishApplet* fish)
 {
-	if (fish->source_id == 0)
-		return;
-
 	char *value;
 
 	value = g_settings_get_string (settings, key);
@@ -1691,13 +1677,13 @@ static void setup_fish_widget(FishApplet* fish)
 }
 
 static const GtkActionEntry fish_menu_verbs[] = {
-	{ "FishPreferences", GTK_STOCK_PROPERTIES, N_("_Preferences"),
+	{ "FishPreferences", "document-properties", N_("_Preferences"),
 	  NULL, NULL,
 	  G_CALLBACK (display_preferences_dialog) },
-	{ "FishHelp", GTK_STOCK_HELP, N_("_Help"),
+	{ "FishHelp", "help-browser", N_("_Help"),
 	  NULL, NULL,
 	  G_CALLBACK (display_help_dialog) },
-	{ "FishAbout", GTK_STOCK_ABOUT, N_("_About"),
+	{ "FishAbout", "help-about", N_("_About"),
 	  NULL, NULL,
 	  G_CALLBACK (display_about_dialog) }
 };
@@ -1778,6 +1764,10 @@ static void fish_applet_dispose (GObject *object)
 {
 	FishApplet* fish = (FishApplet*) object;
 
+	if (fish->settings != NULL)
+		g_signal_handlers_disconnect_by_data (fish->settings,
+					  fish);
+
 	if (fish->timeout)
 	{
 		g_source_remove (fish->timeout);
