@@ -64,15 +64,22 @@ static GfStatusNotifierWatcher *sn_watcher_service = NULL;
 static GfStatusNotifierWatcher *
 sn_watcher_service_ref (void)
 {
-  if (sn_watcher_service != NULL)
-    g_object_ref (sn_watcher_service);
-  else
+  GSettings *settings;
+  settings = g_settings_new ("org.mate.panel");
+
+  if (g_settings_get_boolean (settings, "enable-sni-support") == TRUE)
     {
-      sn_watcher_service = gf_status_notifier_watcher_new ();
-      g_object_add_weak_pointer ((GObject *) sn_watcher_service,
-                                 (gpointer *) &sn_watcher_service);
+      if (sn_watcher_service != NULL)
+        g_object_ref (sn_watcher_service);
+      else
+        {
+          sn_watcher_service = gf_status_notifier_watcher_new ();
+          g_object_add_weak_pointer ((GObject *) sn_watcher_service,
+                                     (gpointer *) &sn_watcher_service);
+        }
     }
 
+  g_object_unref (settings);
   return sn_watcher_service;
 }
 #endif
@@ -104,11 +111,7 @@ static void help_cb(GtkAction* action, NaTrayApplet* applet)
 	#define NA_HELP_DOC "mate-user-guide"
 
 	uri = g_strdup_printf("help:%s/%s", NA_HELP_DOC, "panels-notification-area");
-#if GTK_CHECK_VERSION (3, 22, 0)
 	gtk_show_uri_on_window (NULL, uri, gtk_get_current_event_time (), &error);
-#else
-	gtk_show_uri(gtk_widget_get_screen(GTK_WIDGET(applet)), uri, gtk_get_current_event_time(), &error);
-#endif
 	g_free(uri);
 
 	if (error && g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
@@ -160,7 +163,7 @@ static void about_cb(GtkAction* action, NaTrayApplet* applet)
 		"Copyright \xc2\xa9 2002 Red Hat, Inc.\n"
 		"Copyright \xc2\xa9 2003-2006 Vincent Untz\n"
 		"Copyright \xc2\xa9 2011 Perberos\n"
-		"Copyright \xc2\xa9 2012-2017 MATE developers";
+		"Copyright \xc2\xa9 2012-2018 MATE developers";
 
 	gtk_show_about_dialog(NULL,
 		"program-name", _("Notification Area"),
@@ -175,10 +178,10 @@ static void about_cb(GtkAction* action, NaTrayApplet* applet)
 }
 
 static const GtkActionEntry menu_actions [] = {
-	{ "SystemTrayHelp", GTK_STOCK_HELP, N_("_Help"),
+	{ "SystemTrayHelp", "help-browser", N_("_Help"),
 	  NULL, NULL,
 	  G_CALLBACK (help_cb) },
-	{ "SystemTrayAbout", GTK_STOCK_ABOUT, N_("_About"),
+	{ "SystemTrayAbout", "help-about", N_("_About"),
 	  NULL, NULL,
 	  G_CALLBACK (about_cb) }
 };
@@ -293,26 +296,6 @@ na_tray_applet_focus (GtkWidget        *widget,
   return GTK_WIDGET_CLASS (na_tray_applet_parent_class)->focus (widget, direction);
 }
 
-#if !GTK_CHECK_VERSION (3, 20, 0)
-static inline void
-force_no_focus_padding (GtkWidget *widget)
-{
-  GtkCssProvider *provider;
-
-  provider = gtk_css_provider_new ();
-  gtk_css_provider_load_from_data (provider,
-                                   "NaTrayApplet {\n"
-                                   " -GtkWidget-focus-line-width: 0px;\n"
-                                   " -GtkWidget-focus-padding: 0px;\n"
-				   "}",
-                                   -1, NULL);
-  gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
-                                  GTK_STYLE_PROVIDER (provider),
-                                  GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-  g_object_unref (provider);
-}
-#endif
-
 static void
 na_tray_applet_class_init (NaTrayAppletClass *class)
 {
@@ -354,9 +337,7 @@ na_tray_applet_class_init (NaTrayAppletClass *class)
 
   g_type_class_add_private (class, sizeof (NaTrayAppletPrivate));
 
-#if GTK_CHECK_VERSION (3, 20, 0)
   gtk_widget_class_set_css_name (widget_class, "na-tray-applet");
-#endif
 }
 
 static void
@@ -383,10 +364,6 @@ na_tray_applet_init (NaTrayApplet *applet)
 
   mate_panel_applet_set_flags (MATE_PANEL_APPLET (applet),
                           MATE_PANEL_APPLET_HAS_HANDLE|MATE_PANEL_APPLET_EXPAND_MINOR);
-
-#if !GTK_CHECK_VERSION (3, 20, 0)
-  force_no_focus_padding (GTK_WIDGET (applet));
-#endif
 }
 
 static gboolean
