@@ -126,6 +126,15 @@ layout_parse (SnDBusMenu *menu,
   GVariantIter iter;
   GVariant *child;
 
+  if (!g_variant_is_of_type (layout, G_VARIANT_TYPE ("(ia{sv}av)")))
+    {
+      g_warning ("Type of return value for 'layout' property in "
+                 "'GetLayout' call should be '(ia{sv}av)' but got '%s'",
+                 g_variant_get_type_string (layout));
+
+      return;
+    }
+
   g_variant_get (layout, "(i@a{sv}@av)", &id, &props, &items);
 
   submenu = layout_update_item (menu, gtk_menu, id, props);
@@ -178,11 +187,11 @@ get_layout_cb (GObject      *source_object,
 
   g_hash_table_remove_all (menu->items);
   layout_parse (menu, layout, GTK_MENU (menu));
-#if GTK_CHECK_VERSION (3, 22, 0)
+
   /* Reposition menu to accomodate any size changes   */
   /* Menu size never changes with GTK 3.20 or earlier */
   gtk_menu_reposition(GTK_MENU(menu));
-#endif
+
   g_variant_unref (layout);
 }
 
