@@ -512,6 +512,14 @@ sn_tooltip_new (GVariant *variant)
   if (variant == NULL)
     return NULL;
 
+  if (!g_variant_is_of_type (variant, G_VARIANT_TYPE ("(sa(iiay)ss)")))
+    {
+      g_warning ("Type for 'ToolTip' property should be '(sa(iiay)ss)' "
+                 "but got '%s'", g_variant_get_type_string (variant));
+
+      return NULL;
+    }
+
   g_variant_get (variant, "(&s@a(iiay)&s&s)",
                  &icon_name, &icon_pixmap,
                  &title, &text);
@@ -1364,9 +1372,7 @@ sn_item_v0_class_init (SnItemV0Class *v0_class)
 
   widget_class->size_allocate = sn_item_v0_size_allocate;
 
-#if GTK_CHECK_VERSION (3, 20, 0)
   gtk_widget_class_set_css_name (widget_class, "sn-item");
-#endif
 
   install_properties (object_class);
 }
