@@ -19,12 +19,14 @@
 #define PANEL_PLUG_PRIVATE_H
 
 #include <gtk/gtk.h>
-#if GTK_CHECK_VERSION (3, 18, 0) && GLIB_CHECK_VERSION (2, 44, 0)
-
 #include <gtk/gtkx.h>
 
 G_BEGIN_DECLS
 
+/* G_DECLARE_FINAL_TYPE is available only since GLib 2.44,
+ * but GTK+ 3.18 already requires 2.45.8, so we're safe.
+ */
+
 #define PANEL_TYPE_PLUG panel_plug_get_type ()
 G_DECLARE_FINAL_TYPE (PanelPlug, panel_plug, PANEL, PLUG, GtkPlug)
 
@@ -33,4 +35,3 @@ GtkWidget *panel_plug_new (void);
 G_END_DECLS
 
 #endif
-#endif
