@@ -335,22 +335,16 @@ egg_sm_client_get (void)
     {
       if (!sm_client_disable)
 	{
-#if defined (GDK_WINDOWING_WIN32)
-	  global_client = egg_sm_client_win32_new ();
-#elif defined (GDK_WINDOWING_QUARTZ)
-	  global_client = egg_sm_client_osx_new ();
-#else
 	  /* If both D-Bus and XSMP are compiled in, try XSMP first
 	   * (since it supports state saving) and fall back to D-Bus
 	   * if XSMP isn't available.
 	   */
-# ifdef EGG_SM_CLIENT_BACKEND_XSMP
+#ifdef EGG_SM_CLIENT_BACKEND_XSMP
 	  global_client = egg_sm_client_xsmp_new ();
-# endif
-# ifdef EGG_SM_CLIENT_BACKEND_DBUS
+#endif
+#ifdef EGG_SM_CLIENT_BACKEND_DBUS
 	  if (!global_client)
 	    global_client = egg_sm_client_dbus_new ();
-# endif
 #endif
 	}
 
