@@ -381,10 +381,8 @@ mate_panel_applet_frame_dbus_class_init (MatePanelAppletFrameDBusClass *class)
 	frame_class->change_size = mate_panel_applet_frame_dbus_change_size;
 	frame_class->change_background = mate_panel_applet_frame_dbus_change_background;
 
-#if GTK_CHECK_VERSION (3, 20, 0)
 	GtkWidgetClass *widget_class  = GTK_WIDGET_CLASS (class);
 	gtk_widget_class_set_css_name (widget_class, "MatePanelAppletFrameDBus");
-#endif
 
 	g_type_class_add_private (class, sizeof (MatePanelAppletFrameDBusPrivate));
 }
@@ -415,7 +413,7 @@ mate_panel_applet_frame_dbus_load (const gchar                 *iid,
 	GVariantBuilder       builder;
 	GdkScreen            *screen;
 	gchar                *conf_path;
-	gchar                *background;
+	/*gchar                *background; unused */
 	guint                 orient;
 
 	g_return_val_if_fail (iid != NULL, FALSE);
@@ -433,7 +431,7 @@ mate_panel_applet_frame_dbus_load (const gchar                 *iid,
 	conf_path = mate_panel_applet_frame_activating_get_conf_path (frame_act);
 	/* we can't really get a background string at this point since we don't
 	 * know the position of the applet */
-	background = NULL;
+	/*background = NULL;               */
 
 	g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{sv}"));
 	g_variant_builder_add (&builder, "{sv}",
@@ -451,11 +449,13 @@ mate_panel_applet_frame_dbus_load (const gchar                 *iid,
 	g_variant_builder_add (&builder, "{sv}",
 			       "locked-down",
 			       g_variant_new_boolean (mate_panel_applet_frame_activating_get_locked_down (frame_act)));
+	/*since background has just been set to NULL, this block never executes
 	if (background) {
 		g_variant_builder_add (&builder, "{sv}",
 				       "background",
 				       g_variant_new_string (background));
 	}
+	*/
 
 	g_object_set_data (G_OBJECT (frame), "mate-panel-applet-frame-activating", frame_act);
 
@@ -466,7 +466,7 @@ mate_panel_applet_frame_dbus_load (const gchar                 *iid,
 				    g_variant_builder_end (&builder));
 
 	g_free (conf_path);
-	g_free (background);
+	/*g_free (background); */
 
 	return TRUE;
 }
