@@ -381,9 +381,9 @@ _panel_icon_chooser_clicked (GtkButton *button)
 	filechooser = gtk_file_chooser_dialog_new (_("Choose an icon"),
 						   parent,
 						   GTK_FILE_CHOOSER_ACTION_OPEN,
-						   GTK_STOCK_CANCEL,
+						   "gtk-cancel",
 						   GTK_RESPONSE_CANCEL,
-						   GTK_STOCK_OPEN,
+						   "gtk-open",
 						   GTK_RESPONSE_ACCEPT,
 						   NULL);
 	panel_gtk_file_chooser_add_image_preview (GTK_FILE_CHOOSER (filechooser));
@@ -421,11 +421,7 @@ _panel_icon_chooser_clicked (GtkButton *button)
 
 			if (info) {
 				path = g_strdup (gtk_icon_info_get_filename (info));
-#if GTK_CHECK_VERSION (3, 8, 0)
 				g_object_unref (info);
-#else
-				gtk_icon_info_free (info);
-#endif
 			}
 		}
 
