@@ -417,66 +417,38 @@ add_menu_to_panel (GtkWidget      *menuitem,
 	matemenu_tree_item_unref (directory);
 }
 
-/*most of this function stolen from the real gtk_menu_popup*/
 static void
-restore_grabs(GtkWidget *w, gpointer data)
+grab_widget (GtkWidget *widget)
 {
-	GtkWidget *menu_item = data;
-	GtkMenu *menu = GTK_MENU (gtk_widget_get_parent (menu_item));
-	GtkWidget *xgrab_shell;
-	GtkWidget *parent;
+	g_return_if_fail (widget != NULL);
 
-	/* Find the last viewable ancestor, and make an X grab on it
-	 */
-	parent = GTK_WIDGET (menu);
-	xgrab_shell = NULL;
-	while (parent) {
-		gboolean viewable = TRUE;
-		GtkWidget *tmp = parent;
+	GdkWindow *window;
+	GdkDisplay *display;
+	GdkSeat *seat;
 
-		while (tmp) {
-			if (!gtk_widget_get_mapped (tmp)) {
-				viewable = FALSE;
-				break;
-			}
-			tmp = gtk_widget_get_parent (tmp);
-		}
+	window = gtk_widget_get_window (widget);
+	display = gdk_window_get_display (window);
 
-		if (viewable)
-			xgrab_shell = parent;
+	seat = gdk_display_get_default_seat (display);
+	gdk_seat_grab (seat, window,
+	               GDK_SEAT_CAPABILITY_ALL, TRUE,
+	               NULL, NULL, NULL, NULL);
+}
 
-		parent = gtk_menu_shell_get_parent_shell (GTK_MENU_SHELL (parent));
+static void
+restore_grabs (GtkWidget *menu,
+               GtkWidget *item)
+{
+	GtkWidget *parent = gtk_widget_get_parent (item);
+
+	if (parent) {
+		grab_widget (parent);
 	}
-
-	/*only grab if this HAD a grab before*/
-	/* FIXME fix for GTK3 */
-#if 0
-	if (xgrab_shell && (GTK_MENU_SHELL (xgrab_shell)->have_xgrab))
-          {
-	    GdkWindow *window = gtk_widget_get_window (xgrab_shell);
-
-	    if (gdk_pointer_grab (window, TRUE,
-				  GDK_BUTTON_PRESS_MASK |
-				  GDK_BUTTON_RELEASE_MASK |
-				  GDK_ENTER_NOTIFY_MASK |
-				  GDK_LEAVE_NOTIFY_MASK,
-				  NULL, NULL, 0) == 0)
-              {
-		if (gdk_keyboard_grab (window, TRUE,
-				       GDK_CURRENT_TIME) == 0)
-		  GTK_MENU_SHELL (xgrab_shell)->have_xgrab = TRUE;
-		else
-		  gdk_pointer_ungrab (GDK_CURRENT_TIME);
-	      }
-         }
-#endif
-
-	gtk_grab_add (GTK_WIDGET (menu));
 }
 
 static void
 menu_destroy_context_menu (GtkWidget *item,
-			   GtkWidget *menu)
+                           GtkWidget *menu)
 {
 	g_signal_handlers_disconnect_by_func (menu, restore_grabs, item);
 	gtk_widget_destroy (menu);
@@ -668,60 +640,7 @@ drag_end_menu_cb (GtkWidget *widget, GdkDragContext     *context)
 
   if (xgrab_shell)
     {
-      gboolean status;
-      GdkDisplay *display;
-      GdkDevice *pointer;
-      GdkDevice *keyboard;
-#if GTK_CHECK_VERSION(3, 20, 0)
-      GdkSeat *seat;
-#else
-      GdkDeviceManager *device_manager;
-#endif
-      GdkWindow *window = gtk_widget_get_window (xgrab_shell);
-      GdkCursor *cursor = gdk_cursor_new_for_display (gdk_display_get_default (),
-                                                      GDK_ARROW);
-
-      display = gdk_window_get_display (window);
-#if GTK_CHECK_VERSION(3, 20, 0)
-      seat = gdk_display_get_default_seat (display);
-      pointer = gdk_seat_get_pointer (seat);
-#else
-      device_manager = gdk_display_get_device_manager (display);
-      pointer = gdk_device_manager_get_client_pointer (device_manager);
-#endif
-      keyboard = gdk_device_get_associated_device (pointer);
-
-      /* FIXMEgpoo: Not sure if report to GDK_OWNERSHIP_WINDOW
-         or GDK_OWNERSHIP_APPLICATION Idem for the
-         keyboard below */
-      status = gdk_device_grab (pointer, window,
-                                GDK_OWNERSHIP_WINDOW, TRUE,
-                                GDK_BUTTON_PRESS_MASK
-                                | GDK_BUTTON_RELEASE_MASK
-                                | GDK_ENTER_NOTIFY_MASK
-                                | GDK_LEAVE_NOTIFY_MASK
-                                | GDK_POINTER_MOTION_MASK,
-                                cursor, GDK_CURRENT_TIME);
-
-      if (!status)
-        {
-	  if (gdk_device_grab (keyboard, window,
-			       GDK_OWNERSHIP_WINDOW, TRUE,
-			       GDK_KEY_PRESS | GDK_KEY_RELEASE,
-			       NULL, GDK_CURRENT_TIME) == GDK_GRAB_SUCCESS)
-	    {
-/* FIXME fix for GTK3 */
-#if 0
-          GTK_MENU_SHELL (xgrab_shell)->have_xgrab = TRUE;
-#endif
-	    }
-	  else
-	    {
-	      gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
-	    }
-	}
-
-      g_object_unref (cursor);
+      grab_widget (xgrab_shell);
     }
 }
 
@@ -831,12 +750,8 @@ setup_menuitem (GtkWidget   *menuitem,
 
 	gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (label), menuitem);
 
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
 	gtk_widget_show (label);
 
 	gtk_container_add (GTK_CONTAINER (menuitem), label);
@@ -1177,14 +1092,12 @@ create_menuitem (GtkWidget          *menu,
 
 		if (matemenu_tree_entry_get_icon (entry) != NULL) {
 			const char *icon;
-			char       *icon_no_ext;
+			GIcon      *gicon;
 
 			icon = matemenu_tree_entry_get_icon (entry);
-			if (!g_path_is_absolute (icon)) {
-				icon_no_ext = panel_xdg_icon_remove_extension (icon);
-				gtk_drag_source_set_icon_name (menuitem,
-							       icon_no_ext);
-				g_free (icon_no_ext);
+			gicon = panel_gicon_from_icon_name (icon);
+			if (gicon != NULL) {
+				gtk_drag_source_set_icon_gicon (menuitem, gicon);
 			}
 		}
 
