@@ -101,9 +101,7 @@ panel_action_protocol_filter (GdkXEvent *gdk_xevent,
 {
 	GdkWindow *window;
 	GdkScreen *screen;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkDisplay *display;
-#endif
 	XEvent    *xevent = (XEvent *) gdk_xevent;
 
 	if (xevent->type != ClientMessage)
@@ -113,21 +111,14 @@ panel_action_protocol_filter (GdkXEvent *gdk_xevent,
 	   (xevent->xclient.message_type != atom_gnome_panel_action))
 		return GDK_FILTER_CONTINUE;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	screen = gdk_event_get_screen (event);
 	display = gdk_screen_get_display (screen);
 	window = gdk_x11_window_lookup_for_display (display, xevent->xclient.window);
-#else
-	window = gdk_window_lookup (xevent->xclient.window);
-	screen = gdk_drawable_get_screen (window);
-#endif
 	if (!window)
 		return GDK_FILTER_CONTINUE;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	if (window != gdk_screen_get_root_window (screen))
 		return GDK_FILTER_CONTINUE;
-#endif
 
 	if (xevent->xclient.data.l [0] == atom_mate_panel_action_main_menu)
 		panel_action_protocol_main_menu (screen, xevent->xclient.data.l [1]);
