@@ -503,12 +503,8 @@ label_new_with_mnemonic (const char *text)
 	g_free (bold);
 
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 1.0);
 	gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
-#endif
 
 	gtk_widget_show (label);
 
@@ -653,22 +649,22 @@ panel_ditem_editor_make_ui (PanelDItemEditor *dialog)
 				       priv->comment_entry);
 
 	priv->help_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						   GTK_STOCK_HELP,
+						   "gtk-help",
 						   GTK_RESPONSE_HELP);
 	priv->revert_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						     GTK_STOCK_REVERT_TO_SAVED,
+						     "gtk-revert-to-saved",
 						     REVERT_BUTTON);
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
 					   REVERT_BUTTON,
 					   FALSE);
 	priv->close_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						    GTK_STOCK_CLOSE,
+						    "gtk-close",
 						    GTK_RESPONSE_CLOSE);
 	priv->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						     GTK_STOCK_CANCEL,
+						     "gtk-cancel",
 						     GTK_RESPONSE_CANCEL);
 	priv->ok_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-						 GTK_STOCK_OK,
+						 "gtk-ok",
 						 GTK_RESPONSE_OK);
 
 	/* FIXME: There needs to be a way to edit ALL keys/sections */
@@ -1009,9 +1005,9 @@ command_browse_button_clicked (PanelDItemEditor *dialog)
 
 	chooser = gtk_file_chooser_dialog_new ("", GTK_WINDOW (dialog),
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
-					       GTK_STOCK_CANCEL,
+					       "gtk-cancel",
 					       GTK_RESPONSE_CANCEL,
-					       GTK_STOCK_OPEN,
+					       "gtk-open",
 					       GTK_RESPONSE_ACCEPT,
 					       NULL);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (chooser), TRUE);
