@@ -270,11 +270,7 @@ static void panel_menu_bar_size_allocate(GtkWidget* widget, GtkAllocation* alloc
 		return;
 	}
 
-#if GTK_CHECK_VERSION (3, 18, 0)
 	background = &PANEL_MENU_BAR(widget)->priv->panel->toplevel->background;
-#else
-	background = &PANEL_MENU_BAR(widget)->priv->panel->background;
-#endif
 	if (background->type == PANEL_BACK_NONE || (background->type == PANEL_BACK_COLOR && !background->has_alpha))
 	{
 		return;
@@ -356,12 +352,12 @@ static void panel_menu_bar_load(PanelWidget* panel, gboolean locked, int positio
 	settings = gtk_settings_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (panel)));
 	g_object_set (settings, "gtk-shell-shows-app-menu", FALSE, "gtk-shell-shows-menubar", FALSE, NULL);
 
-	mate_panel_applet_add_callback(menubar->priv->info, "help", GTK_STOCK_HELP, _("_Help"), NULL);
+	mate_panel_applet_add_callback(menubar->priv->info, "help", "help-browser", _("_Help"), NULL);
 
 	/* Menu editors */
 	if (!panel_lockdown_get_locked_down () && (panel_is_program_in_path("mozo") || panel_is_program_in_path("menulibre")))
 	{
-		mate_panel_applet_add_callback (menubar->priv->info, "edit", NULL, _("_Edit Menus"), NULL);
+		mate_panel_applet_add_callback (menubar->priv->info, "edit", "document-properties", _("_Edit Menus"), NULL);
 	}
 
 	g_signal_connect_after(menubar, "focus-in-event", G_CALLBACK(gtk_widget_queue_draw), menubar);
@@ -434,11 +430,7 @@ void panel_menu_bar_popup_menu(PanelMenuBar* menubar, guint32 activate_time)
 
 void panel_menu_bar_change_background(PanelMenuBar* menubar)
 {
-#if GTK_CHECK_VERSION (3, 18, 0)
 	panel_background_apply_css(&menubar->priv->panel->toplevel->background, GTK_WIDGET(menubar));
-#else
-	panel_background_apply_css(&menubar->priv->panel->background, GTK_WIDGET(menubar));
-#endif
 }
 
 static void set_item_text_gravity(GtkWidget* item)
@@ -468,12 +460,8 @@ static void set_item_text_angle_and_alignment(GtkWidget* item, double text_angle
 
 	gtk_label_set_angle (GTK_LABEL (label), text_angle);
 
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), xalign);
 	gtk_label_set_yalign (GTK_LABEL (label), yalign);
-#else
-	gtk_misc_set_alignment (GTK_MISC (label), xalign, yalign);
-#endif
 }
 
 static void panel_menu_bar_update_orientation(PanelMenuBar* menubar)
