@@ -291,7 +291,7 @@ panel_run_dialog_set_icon (PanelRunDialog *dialog,
 		gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &size, NULL);
 
 		GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();
-		GtkIconInfo *icon_info = gtk_icon_theme_lookup_by_gicon (icon_theme, icon, size, 0);
+		GtkIconInfo *icon_info = gtk_icon_theme_lookup_by_gicon (icon_theme, icon, size, GTK_ICON_LOOKUP_FORCE_SIZE);
 		pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
 		g_object_unref (icon_info);
 	}
@@ -1118,6 +1118,7 @@ static void
 panel_run_dialog_update_content (PanelRunDialog *dialog,
 				 gboolean        show_list)
 {
+
 	if (!panel_profile_get_enable_program_list ()) {
 		GtkWidget *parent;
 
@@ -1131,8 +1132,9 @@ panel_run_dialog_update_content (PanelRunDialog *dialog,
 
 	} else {
 
-        /* if the list is closed and the user wants to see it */
-        if (show_list && !gtk_expander_get_expanded (GTK_EXPANDER (dialog->list_expander))) {
+        /* the following two conditions occur, when the user clicks the expander in the dialog
+         * if the list is closed and the user wants to see it */
+        if (show_list && gtk_expander_get_expanded (GTK_EXPANDER (dialog->list_expander))) {
 
             /* open the expander, this shows the list */
             gtk_expander_set_expanded (GTK_EXPANDER (dialog->list_expander), TRUE);
@@ -1142,7 +1144,7 @@ panel_run_dialog_update_content (PanelRunDialog *dialog,
             gtk_widget_grab_focus (dialog->program_list);
 
         /* if the list is open and the user wants to close it */
-        } else if (!show_list && gtk_expander_get_expanded (GTK_EXPANDER (dialog->list_expander))) {
+        } else if (!show_list && !gtk_expander_get_expanded (GTK_EXPANDER (dialog->list_expander))) {
 
             /* close the expander, this hides the list */
             gtk_expander_set_expanded (GTK_EXPANDER (dialog->list_expander), FALSE);
@@ -1150,6 +1152,19 @@ panel_run_dialog_update_content (PanelRunDialog *dialog,
             gtk_window_set_resizable (GTK_WINDOW (dialog->run_dialog), FALSE);
             gtk_widget_grab_focus (dialog->combobox);
         }
+
+        /* the following two conditions occur, when the user changes the expander setting in GSettings */
+        if (show_list && !gtk_expander_get_expanded (GTK_EXPANDER (dialog->list_expander))) {
+
+            /* open the expander, this shows the list */
+            gtk_expander_set_expanded (GTK_EXPANDER (dialog->list_expander), TRUE);
+
+        /* if the list is open and the user wants to close it */
+        } else if (!show_list && gtk_expander_get_expanded (GTK_EXPANDER (dialog->list_expander))) {
+
+            /* close the expander, this hides the list */
+            gtk_expander_set_expanded (GTK_EXPANDER (dialog->list_expander), FALSE);
+        }
     }
 }
 
@@ -1708,7 +1723,6 @@ panel_run_dialog_setup_entry (PanelRunDialog *dialog,
 	GdkScreen             *screen;
 	int                    width_request;
 	GtkWidget             *entry;
-	gint                   scale;
 
 	dialog->combobox = PANEL_GTK_BUILDER_GET (gui, "comboboxentry");
 
@@ -1721,10 +1735,9 @@ panel_run_dialog_setup_entry (PanelRunDialog *dialog,
 		(GTK_COMBO_BOX (dialog->combobox), 0);
 
 	screen = gtk_window_get_screen (GTK_WINDOW (dialog->run_dialog));
-	scale = gtk_widget_get_scale_factor (GTK_WIDGET (dialog->run_dialog));
 
         /* 1/4 the width of the first monitor should be a good value */
-	width_request = panel_multiscreen_width (screen, 0) / (4 * scale);
+	width_request = panel_multiscreen_width (screen, 0) / 4;
 	g_object_set (G_OBJECT (dialog->combobox),
 		      "width_request", width_request,
 		      NULL);
@@ -1894,6 +1907,35 @@ panel_run_dialog_setup_pixmap (PanelRunDialog *dialog,
 			  dialog);
 }
 
+/* this runs after entry_event() */
+static gboolean
+key_press_event (GtkWidget    *run_dialog,
+				GdkEventKey    *event,
+				PanelRunDialog *dialog)
+{
+
+	/* allow only key presses */
+	if (event->type != GDK_KEY_PRESS)
+		return FALSE;
+
+	/* If the program list is enabled and open and the user presses the F6 key
+	 * the focus should jump between GtkComboBoxText and the program list  */
+	if (panel_profile_get_enable_program_list () && panel_profile_get_show_program_list () && event->keyval == GDK_KEY_F6) {
+
+		/* jump to the program list from anywhere */
+		if (!gtk_widget_has_focus (dialog->program_list)) {
+			gtk_widget_grab_focus (dialog->program_list);
+		/* on the program list, jump to the entry box */
+		} else {
+			gtk_widget_grab_focus (dialog->combobox);
+		}
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static PanelRunDialog *
 panel_run_dialog_new (GdkScreen  *screen,
 		      GtkBuilder *gui,
@@ -1922,6 +1964,10 @@ panel_run_dialog_new (GdkScreen  *screen,
 	panel_run_dialog_setup_program_list  (dialog, gui);
 	panel_run_dialog_setup_list_expander (dialog, gui);
 
+    /* key press event signal for the whole dialog */
+	g_signal_connect (dialog->run_dialog, "key-press-event",
+			  G_CALLBACK (key_press_event), dialog);
+
 	panel_run_dialog_set_default_icon    (dialog, FALSE);
 
 	panel_run_dialog_update_content (dialog, panel_profile_get_show_program_list ());
