@@ -157,12 +157,7 @@ back_change (AppletInfo  *info,
 	switch (info->type) {
 	case PANEL_OBJECT_APPLET:
 		mate_panel_applet_frame_change_background (
-
-#if GTK_CHECK_VERSION (3, 18, 0)
 		MATE_PANEL_APPLET_FRAME (info->widget), panel->toplevel->background.type);
-#else
-		MATE_PANEL_APPLET_FRAME (info->widget), panel->background.type);
-#endif
 		break;
 	case PANEL_OBJECT_MENU_BAR:
 		panel_menu_bar_change_background (PANEL_MENU_BAR (info->widget));
@@ -1348,8 +1343,8 @@ panel_deletion_dialog (PanelToplevel *toplevel)
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 	                                          "%s", text2);	
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_DELETE, GTK_RESPONSE_OK,
+				"gtk-cancel", GTK_RESPONSE_CANCEL,
+				"gtk-delete", GTK_RESPONSE_OK,
 				NULL);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
