@@ -335,7 +335,8 @@ xstuff_zoom_animate (GtkWidget *widget,
 	GdkScreen *gscreen;
 	GdkRectangle rect, dest;
 	GtkAllocation allocation;
-	int monitor;
+	GdkMonitor *monitor;
+	GdkDisplay *display;
 
 	if (opt_rect)
 		rect = *opt_rect;
@@ -358,9 +359,10 @@ xstuff_zoom_animate (GtkWidget *widget,
 						rect.width, rect.height,
 						pixbuf, orientation);
 	else {
-		monitor = gdk_screen_get_monitor_at_window (gscreen,
-							    gtk_widget_get_window (widget));
-		gdk_screen_get_monitor_geometry (gscreen, monitor, &dest);
+		display = gdk_screen_get_display (gscreen);
+		monitor = gdk_display_get_monitor_at_window (display,
+							     gtk_widget_get_window (widget));
+		gdk_monitor_get_geometry (monitor, &dest);
 
 		draw_zoom_animation (gscreen,
 				     rect.x, rect.y, rect.width, rect.height,
